import { faXmark } from "@fortawesome/pro-solid-svg-icons"
import { faRotateLeft } from "@fortawesome/pro-regular-svg-icons"
import { FontAwesomeIcon } from "@fortawesome/react-fontawesome"
import { useState } from "react"
import Setting from "./Setting"

const settingOptionsInit: { [key: string]: boolean } = {
  allowSpectators: false,
  allowSpecials: false,
  allowChat: false,
  allowMarkDraw: false,
}

function Settings({ closeSettings }: { closeSettings: () => void }) {
  const [settingOptions, setSettingOptions] = useState(settingOptionsInit)
  return (
    <div className="absolute inset-0 flex flex-col justify-center bg-black bg-opacity-40">
      <div className="relative mx-16 flex flex-col rounded-3xl border-4 border-zinc-700 bg-zinc-400 p-8">
        <h1 className="font-farro text-center text-6xl font-semibold text-white shadow-black drop-shadow-lg">
          Settings
        </h1>
        <button
          className="absolute top-6 right-6  h-14 w-14 "
          onClick={closeSettings}
        >
          <FontAwesomeIcon
            className="h-full w-full text-gray-700 drop-shadow-md"
            icon={faXmark}
          />
        </button>
        <div className="relative m-8 rounded-xl bg-zinc-500 pt-16">
          <button
            className="absolute top-8 right-12  h-14 w-14"
            onClick={() => setSettingOptions(settingOptionsInit)}
          >
            <FontAwesomeIcon
              className="h-full w-full text-gray-700 drop-shadow-md"
              icon={faRotateLeft}
            />
          </button>
          <div className="mr-32 grid grid-cols-3 items-center justify-items-start gap-4 p-8">
            {Object.keys(settingOptions).map((key) => {
              const state = settingOptions[key]
              const onClick = () =>
                setSettingOptions((e) => ({ ...e, [key]: !e[key] }))
              return <Setting key={key} props={{ key, state, onClick }} />
            })}
          </div>
        </div>
      </div>
    </div>
  )
}

export default Settings
